@@ -1168,8 +1168,9 @@ LOCAL void dns_save(BSB *jbsb, ArkimeFieldObject_t *object, struct arkime_sessio
 #endif
 
     BSB_EXPORT_sprintf(*jbsb, "\"opcode\":\"%s\",", dns->query.opcode);
-    BSB_EXPORT_sprintf(*jbsb, "\"queryHost\":\"%s\",", dns->query.hostname);
-    BSB_EXPORT_sprintf(*jbsb, "\"qc\":\"%s\",", dns->query.class);
+    BSB_EXPORT_sprintf(*jbsb, "\"queryHost\":");
+    arkime_db_js0n_str(jbsb, (uint8_t *)dns->query.hostname, TRUE);
+    BSB_EXPORT_sprintf(*jbsb, ",\"qc\":\"%s\",", dns->query.class);
     BSB_EXPORT_sprintf(*jbsb, "\"qt\":\"%s\",", dns->query.type);
 
     if (HASH_COUNT(s_, dns->hosts) > 0) {
@@ -1255,7 +1256,7 @@ LOCAL void dns_save(BSB *jbsb, ArkimeFieldObject_t *object, struct arkime_sessio
                     break;
                     case DNS_RR_TXT: {
                         BSB_EXPORT_cstr(*jbsb, "\"txt\":");
-                        arkime_db_js0n_str(jbsb, (uint8_t *)answer->txt, 1);
+                        arkime_db_js0n_str(jbsb, (uint8_t *)answer->txt, TRUE);
                         BSB_EXPORT_u08(*jbsb, ',');
                         g_free(answer->txt);
                     }
@@ -1325,7 +1326,7 @@ LOCAL void dns_save(BSB *jbsb, ArkimeFieldObject_t *object, struct arkime_sessio
                     break;
                     case DNS_RR_CAA: {
                         BSB_EXPORT_sprintf(*jbsb, "\"caa\":\"CAA %d %s ", answer->caa->flags, answer->caa->tag);
-                        arkime_db_js0n_str_unquoted(jbsb, (uint8_t *)answer->caa->value, strlen(answer->caa->value), 1);
+                        arkime_db_js0n_str_unquoted(jbsb, (uint8_t *)answer->caa->value, strlen(answer->caa->value), TRUE);
                         BSB_EXPORT_cstr(*jbsb, "\",");
                         g_free(answer->caa->tag);
                         g_free(answer->caa->value);
@@ -1340,10 +1341,16 @@ LOCAL void dns_save(BSB *jbsb, ArkimeFieldObject_t *object, struct arkime_sessio
                         BSB_EXPORT_sprintf(*jbsb, "\"type\":\"%s\",", answer->type);
                     BSB_EXPORT_sprintf(*jbsb, "\"ttl\":%u,", answer->ttl);
 
-                    BSB_EXPORT_sprintf(*jbsb, "\"name\":\"%s\",", answer->name);
 
-                    if (answer->name && answer->name != root) {
-                        g_free(answer->name);
+                    if (answer->name) {
+                        if (answer->name != root) {
+                            BSB_EXPORT_sprintf(*jbsb, "\"name\":");
+                            arkime_db_js0n_str(jbsb, (uint8_t *)answer->name, TRUE);
+                            BSB_EXPORT_u08(*jbsb, ',');
+                            g_free(answer->name);
+                        } else {
+                            BSB_EXPORT_sprintf(*jbsb, "\"name\":\"%s\",", answer->name);
+                        }
                     }
 
                     ARKIME_TYPE_FREE(DNSAnswer_t, answer);
@@ -1574,10 +1581,10 @@ LOCAL void *dns_getcb_host(const ArkimeSession_t *session, int UNUSED(pos))
 
     HASH_FORALL2(o_, *ohash, object) {
         const DNS_t *dns = (DNS_t *)object->object;
-        g_hash_table_insert(hash, dns->query.hostname, (void *)1LL);
+        g_hash_table_insert(hash, dns->query.hostname, GINT_TO_POINTER(1));
         ArkimeString_t *hstring;
         HASH_FORALL2(s_, dns->hosts, hstring) {
-            g_hash_table_insert(hash, hstring->str, (void *)1LL);
+            g_hash_table_insert(hash, hstring->str, GINT_TO_POINTER(1));
         }
     }
 
@@ -1600,7 +1607,7 @@ LOCAL void *dns_getcb_host_mailserver(const ArkimeSession_t *session, int UNUSED
         if (dns->mxHosts) {
             ArkimeString_t *hstring;
             HASH_FORALL2(s_, *(dns->mxHosts), hstring) {
-                g_hash_table_insert(hash, hstring->str, (void *)1LL);
+                g_hash_table_insert(hash, hstring->str, GINT_TO_POINTER(1));
             }
         }
     }
@@ -1624,7 +1631,7 @@ LOCAL void *dns_getcb_host_nameserver(const ArkimeSession_t *session, int UNUSED
         if (dns->nsHosts) {
             ArkimeString_t *hstring;
             HASH_FORALL2(s_, *(dns->nsHosts), hstring) {
-                g_hash_table_insert(hash, hstring->str, (void *)1LL);
+                g_hash_table_insert(hash, hstring->str, GINT_TO_POINTER(1));
             }
         }
     }
@@ -1648,7 +1655,7 @@ LOCAL void *dns_getcb_puny(const ArkimeSession_t *session, int UNUSED(pos))
         if (dns->punyHosts) {
             ArkimeString_t *hstring;
             HASH_FORALL2(s_, *(dns->punyHosts), hstring) {
-                g_hash_table_insert(hash, hstring->str, (void *)1LL);
+                g_hash_table_insert(hash, hstring->str, GINT_TO_POINTER(1));
             }
         }
     }
@@ -1670,7 +1677,7 @@ LOCAL void *dns_getcb_status(const ArkimeSession_t *session, int UNUSED(pos))
     HASH_FORALL2(o_, *ohash, object) {
         const DNS_t *dns = (DNS_t *)object->object;
         if (dns->rcode)
-            g_hash_table_insert(hash, dns->rcode, (void *)1LL);
+            g_hash_table_insert(hash, dns->rcode, GINT_TO_POINTER(1));
     }
 
     arkime_free_later(hash, (GDestroyNotify) g_hash_table_destroy);
@@ -1690,7 +1697,7 @@ LOCAL void *dns_getcb_opcode(const ArkimeSession_t *session, int UNUSED(pos))
     HASH_FORALL2(o_, *ohash, object) {
         const DNS_t *dns = (DNS_t *)object->object;
         if (dns->query.opcode)
-            g_hash_table_insert(hash, dns->query.opcode, (void *)1LL);
+            g_hash_table_insert(hash, dns->query.opcode, GINT_TO_POINTER(1));
     }
 
     arkime_free_later(hash, (GDestroyNotify) g_hash_table_destroy);
@@ -1710,7 +1717,7 @@ LOCAL void *dns_getcb_query_type(const ArkimeSession_t *session, int UNUSED(pos)
     HASH_FORALL2(o_, *ohash, object) {
         const DNS_t *dns = (DNS_t *)object->object;
         if (dns->query.type)
-            g_hash_table_insert(hash, dns->query.type, (void *)1LL);
+            g_hash_table_insert(hash, dns->query.type, GINT_TO_POINTER(1));
     }
 
     arkime_free_later(hash, (GDestroyNotify) g_hash_table_destroy);
@@ -1730,7 +1737,7 @@ LOCAL void *dns_getcb_query_class(const ArkimeSession_t *session, int UNUSED(pos
     HASH_FORALL2(o_, *ohash, object) {
         const DNS_t *dns = (DNS_t *)object->object;
         if (dns->query.class)
-            g_hash_table_insert(hash, dns->query.class, (void *)1LL);
+            g_hash_table_insert(hash, dns->query.class, GINT_TO_POINTER(1));
     }
 
     arkime_free_later(hash, (GDestroyNotify) g_hash_table_destroy);
@@ -1749,7 +1756,7 @@ LOCAL void *dns_getcb_query_host(const ArkimeSession_t *session, int UNUSED(pos)
 
     HASH_FORALL2(o_, *ohash, object) {
         const DNS_t *dns = (DNS_t *)object->object;
-        g_hash_table_insert(hash, dns->query.hostname, (void *)1LL);
+        g_hash_table_insert(hash, dns->query.hostname, GINT_TO_POINTER(1));
     }
 
     arkime_free_later(hash, (GDestroyNotify) g_hash_table_destroy);
