@@ -507,7 +507,7 @@ LOCAL gboolean reader_libpcapfile_read()
         if (!config.dryRun && !config.copyPcap) {
             // Make sure the output file has been opened otherwise we can't update the entry
             while (lastPacketsBatched > 0 && (offlineInfo[readerPos].outputId == 0 || arkime_http_queue_length_best(esServer) > 0)) {
-                g_main_context_iteration(NULL, TRUE);
+                g_main_context_iteration(NULL, FALSE);
             }
             arkime_db_update_file(offlineInfo[readerPos].outputId, lastBytes, lastBytes, lastPackets, &lastPacketTime);
         }
@@ -533,7 +533,7 @@ LOCAL void reader_libpcapfile_opened()
 
     if (config.flushBetween) {
         arkime_session_flush();
-        g_main_context_iteration(NULL, TRUE);
+        g_main_context_iteration(NULL, FALSE);
         int rc[4];
 
         // Pause until all packets and commands are done
@@ -542,7 +542,7 @@ LOCAL void reader_libpcapfile_opened()
                 LOG("Waiting next file %d %d %d %d", rc[0], rc[1], rc[2], rc[3]);
             }
             usleep(5000);
-            g_main_context_iteration(NULL, TRUE);
+            g_main_context_iteration(NULL, FALSE);
         }
     }
 
